import yargs from 'yargs'
import fs from 'fs'
import opn from 'opn'
import path from 'path'

const enum Layout {
  Top = 'top',
  TopLeft = 'top-left',
  TopRight = 'top-right',
  TopLeftRightBottom = 'top-left-right-bottom',
  TopBottomLeftRight = 'top-bottom-left-right', 
  LeftTop = 'left-top',
  LeftTopBottom = 'left-top-bottom'
}

const BUILDIN_LAYOUTS: ReadonlyArray<Layout> = [
  Layout.Top,
  Layout.TopLeft,
  Layout.TopRight,
  Layout.TopLeftRightBottom,
  Layout.TopBottomLeftRight,  
  Layout.LeftTop,
  Layout.LeftTopBottom
]

export default function main(): void {
  yargs
    .strict()
    .command({
      command: `$0 <layout>`,
      describe: 'available layouts',
      handler,
      builder: (yargs: yargs.Argv): yargs.Argv => {
        return yargs.positional('layout', {
          describe: 'layout',
          type: 'string',
          choices: (BUILDIN_LAYOUTS as string[]).concat('all')
        })
      }
    })
    .version()
    .alias('v', 'version')
    .help('h')
    .alias('h', 'help')
    .argv
}

function handler(argv: yargs.Arguments): void {
  const layout = argv.layout as Layout
  const template = path.resolve(__dirname, `../afdesign`, `${layout}.afdesign`)
  if(!fs.existsSync(template)) throw new Error(`Template not found`)
  opn(template)
  console.log(layout, template)
}

main()
